"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.PostgreDbAdapter = void 0;
const config_1 = require("@eicrud/core/config");
const core_1 = require("@mikro-orm/core");
class PostgreDbAdapter extends config_1.CrudDbAdapter {
    async onModuleInit(orm) { }
    convertColumnName(str) {
        return str
            .split(/(?=[A-Z])/)
            .join('_')
            .toLowerCase();
    }
    getIncrementUpdate(increments, entity, ctx) {
        let updateSql = {};
        for (let key in increments) {
            if (key.includes('.')) {
                const [root, rest] = key.split(/\.(.*)/s);
                const columnName = this.convertColumnName(root);
                updateSql[root] = (0, core_1.raw)(`jsonb_set(COALESCE("${columnName}"::jsonb, '{}'::jsonb), '{${rest}}', (COALESCE("${columnName}"::text::jsonb->>'${rest}','0')::int + ${increments[key]})::text::jsonb)`);
            }
            else {
                updateSql[key] = (0, core_1.raw)(`COALESCE("${this.convertColumnName(key)}",0) + ${increments[key]}`);
            }
        }
        return updateSql;
    }
    getSetUpdate(updates) {
        let updateSql = {};
        for (let key in updates) {
            let update = updates[key];
            if (key.includes('.')) {
                const [root, rest] = key.split(/\.(.*)/s);
                const columnName = this.convertColumnName(root);
                if (update instanceof Date) {
                    update = update.toISOString();
                }
                if (typeof update === 'string') {
                    update = `"${update}"`;
                }
                updateSql[root] = (0, core_1.raw)(`jsonb_set(COALESCE("${columnName}"::jsonb, '{}'::jsonb), '{${rest}}', '${update}'::text::jsonb)`);
            }
            else {
                updateSql[key] = update;
            }
        }
        return updateSql;
    }
    createNewId(str) {
        return str || Math.random().toString(36).substring(7);
    }
    makeInQuery(ids, query) {
        query[this.crudConfig.id_field] = { $in: ids };
    }
    checkId(id) {
        return id;
    }
    createId(crudConfig) {
        let id = Math.random().toString(36).substring(7);
        return this.formatId(id, crudConfig);
    }
    formatId(id, crudConfig) {
        return id;
    }
}
exports.PostgreDbAdapter = PostgreDbAdapter;
